@@ -1,7 +1,7 @@
 // float_precision().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/sfloat.h"
@@ -9,10 +9,10 @@
 
 // Implementation.
 
-#include "cl_SF.h"
+#include "float/sfloat/cl_SF.h"
 
-#include "cl_inline.h"
-#include "cl_SF_zerop.cc"
+#include "base/cl_inline.h"
+#include "float/sfloat/elem/cl_SF_zerop.cc"
 
 namespace cln {
 
