@@ -1,18 +1,18 @@
 // cl_atan_recip().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_F_tran.h"
+#include "float/transcendental/cl_F_tran.h"
 
 
 // Implementation.
 
 #include "cln/integer.h"
 #include "cln/lfloat.h"
-#include "cl_LF.h"
-#include "cl_LF_tran.h"
+#include "float/lfloat/cl_LF.h"
+#include "float/transcendental/cl_LF_tran.h"
 
 #undef floor
 #include <cmath>
