@@ -1,16 +1,18 @@
 // cosh().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
-#include "cl_float.h"
-#include "cl_R.h"
+#include "cln/float.h"
+#include "real/cl_R.h"
+
+namespace cln {
 
 const cl_R cosh (const cl_R& x)
 {
@@ -28,3 +30,5 @@ const cl_R cosh (const cl_R& x)
 		return cosh(x);
 	}
 }
+
+}  // namespace cln
